@@ -3,9 +3,22 @@ from django.contrib.contenttypes import generic
 from django.db import models
 
 
+class DummyParentModel(models.Model):
+    """Dummy to be used in test cases of the ``generic_positions`` app."""
+    name = models.CharField(max_length=256, blank=True)
+
+    generic_position = generic.GenericRelation(
+        'generic_positions.ObjectPosition'
+    )
+
+    def __unicode__(self):
+        return self.name
+
+
 class DummyModel(models.Model):
     """Dummy to be used in test cases of the ``generic_positions`` app."""
     name = models.CharField(max_length=256, blank=True)
+    parent = models.ForeignKey(DummyParentModel)
 
     def __unicode__(self):
         return self.name
